use crate::handles::redis::remove_this_connection;
use crate::typing::used_typed::{ConnectionMap, TaskMap};

pub async fn handle_connection_error(
    from_id: &str,
    connections: &ConnectionMap,
    tasks: &TaskMap,
) {
    println!("开始处理用户id: {} 的连接错误", from_id);
    // 从全局连接映射中移除该连接
    let removed = {
        let mut connections = connections.lock().await;
        let result = connections.remove(from_id).is_some();
        drop(connections); // 提前释放锁
        result
    };

    println!(
        "是否成功从全局连接映射中移除用户id: {}，结果: {}",
        from_id, removed
    );

    // 从 Redis 中移除该用户的信息
    if removed {
        if let Err(e) = remove_this_connection(from_id).await {
            println!("从 Redis 中移除用户信息时出错: {}", e);
        }
    }

    println!("开始尝试关闭用户id: {} 的 redis 连接", from_id);

    // 取消对应的任务
    {
        let mut tasks = tasks.lock().unwrap();
        match tasks.remove(from_id) {
            Some(task) => {
                task.abort();
                println!("成功取消用户id: {} 的任务", from_id);
            }
            None => println!("未在全局任务映射中找到用户id: {} 的任务", from_id),
        }
    }

    println!("断开与用户id: {} 的连接并完成清理操作", from_id);
}