use crate::config::config::REDIS_ADDR;
use lazy_static::lazy_static;
use redis::Client;
use redis::Commands;
use redis_pool::SingleRedisPool;
use std::collections::HashMap;

lazy_static! {
    static ref REDIS_POOL: SingleRedisPool = {
        let client = Client::open(REDIS_ADDR).expect("Failed to connect to Redis");
        redis_pool::RedisPool::new(client, 16, Some(512))
    };
}

// 从 Redis 的 onlineUsers 集合中移除当前用户的信息
pub async fn remove_this_connection(from_id: &str) -> Result<(), redis::RedisError> {
    let mut con = REDIS_POOL
        .get_connection()
        .expect("Failed to get Redis connection");

    if let Err(e) = con.hdel::<&str, &str, ()>("onlineUsers", from_id) {
        println!("从 Redis 中的 onlineUsers 哈希表删除用户信息时出错: {}", e);
        return Err(e);
    }

    println!("成功从 Redis 中移除用户id: {} 的信息", from_id);
    Ok(())
}

// 将当前用户的信息插入到 Redis 的 onlineUsers 集合中
pub async fn insert_this_connection(
    from_id: &str,
    params: &HashMap<String, String>,
) -> Result<(), redis::RedisError> {
    let mut con = REDIS_POOL
        .get_connection()
        .expect("Failed to get Redis connection");

    let device_id = params.get("deviceId").cloned().unwrap_or_default();
    let from_name = params.get("fromName").cloned().unwrap_or_default();

    let user_info_str = format!(
        "{},{},{},1,1,0,0,{}",
        "idle",
        "",
        device_id,
        from_name
    );

    if let Err(e) = con.hset::<&str, &str, &str, ()>("onlineUsers", from_id, &user_info_str) {
        println!(
            "将用户信息添加到 Redis 中的 onlineUsers 哈希表时出错: {}",
            e
        );
        return Err(e);
    }

    println!("成功将用户id: {} 的信息插入到 Redis 中", from_id);
    Ok(())
}