use std::collections::HashMap;
use std::sync::{Arc, Mutex};
use tokio::sync::Mutex as AsyncMutex;
use tokio::task::JoinHandle;
use tokio_tungstenite::WebSocketStream;
use tungstenite::Message;

// 自定义结构体来存储发送器和接收器
#[derive(Debug)]
pub struct Connection {
    pub(crate) sender: futures::stream::SplitSink<WebSocketStream<tokio::net::TcpStream>, Message>,
    pub(crate) receiver: futures::stream::SplitStream<WebSocketStream<tokio::net::TcpStream>>,
}

// 全局连接映射，存储 fromId 到 Connection 的映射
pub type ConnectionMap = Arc<AsyncMutex<HashMap<String, Connection>>>;
// 全局任务映射，存储 fromId 到 JoinHandle 的映射
pub type TaskMap = Arc<Mutex<HashMap<String, JoinHandle<()>>>>;
